@@ -1,5 +1,5 @@
 /* auparse.c --
- * Copyright 2006-08,2012-16 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2006-08,2012-17 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -33,7 +33,12 @@
 #include <unistd.h>
 #include <stdio_ext.h>
 
+//#define LOL_EVENTS_DEBUG01	1	// add debug for list of list event
+					// processing
+
+#ifdef LOL_EVENTS_DEBUG01
 static int debug = 0;
+#endif
 
 static void init_lib(void) __attribute__ ((constructor));
 static void init_lib(void)
@@ -230,8 +235,10 @@ static event_list_t *au_get_ready_event(auparse_state_t *au, int is_test)
         int i;
 	au_lol *lol = au->au_lo;
 	
-	if (au->au_ready == 0)
+	if (au->au_ready == 0) {
+		//if (debug) printf("No events ready\n");
 		return NULL;
+	}
 
         for (i=0; i<=lol->maxi; i++) {
                 au_lolnode *cur = &(lol->array[i]);
@@ -283,7 +290,8 @@ static void au_check_events(auparse_state_t *au, time_t sec)
 				r->type == AUDIT_PROCTITLE ||
 				r->type == AUDIT_EOE || 
 				r->type < AUDIT_FIRST_EVENT ||
-				r->type >= AUDIT_FIRST_ANOM_MSG) {
+				r->type >= AUDIT_FIRST_ANOM_MSG ||
+				r->type == AUDIT_KERNEL) {
                                 // If known to be 1 record event, we are done
 				cur->status = EBS_COMPLETE;
 				au->au_ready++;
@@ -310,11 +318,12 @@ static void au_terminate_all_events(auparse_state_t *au)
                 if (cur->status == EBS_BUILDING) {
                         cur->status = EBS_COMPLETE;
 			au->au_ready++;
+			//if (debug) printf("%d events complete\n", au->au_ready);
                 }
         }
 }
 
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 /*
  * print_list_t	- Print summary of event's records
  * Args:
@@ -424,11 +433,8 @@ auparse_state_t *auparse_init(ausource_t source, const void *b)
 	switch (source)
 	{
 		case AUSOURCE_LOGS:
-			if (geteuid()) {
-				errno = EPERM;
+			if (setup_log_file_array(au))
 				goto bad_exit;
-			}
-			setup_log_file_array(au);
 			break;
 		case AUSOURCE_FILE:
 			if (b == NULL)
@@ -515,12 +521,12 @@ auparse_state_t *auparse_init(ausource_t source, const void *b)
 	au->escape_mode = AUPARSE_ESC_TTY;
 	au->message_mode = MSG_QUIET;
 	au->debug_message = DBG_NO;
-	init_classify(&au->cl_data);
+	init_normalizer(&au->norm_data);
 
 	return au;
 bad_exit:
 	databuf_free(&au->databuf);
-	/* Feee list of events list (au_lo) structure */
+	/* Free list of events list (au_lo) structure */
 	au_lol_clear(au->au_lo, 0);
 	free(au->au_lo);
 	free(au);
@@ -548,6 +554,7 @@ void auparse_add_callback(auparse_state_t *au, auparse_callback_ptr callback,
 
 static void consume_feed(auparse_state_t *au, int flush)
 {
+	//if (debug) printf("consume feed, flush %d\n", flush);
 	while (auparse_next_event(au) > 0) {
 		if (au->callback) {
 			(*au->callback)(au, AUPARSE_CB_EVENT_READY,
@@ -566,12 +573,17 @@ static void consume_feed(auparse_state_t *au, int flush)
 		 */
 		event_list_t	*l;
 
-		if (debug) printf("terminate all events in flush\n");
+		//if (debug) printf("terminate all events in flush\n");
 		au_terminate_all_events(au);
 		while ((l = au_get_ready_event(au, 0)) != NULL) {
+			rnode *r;
 			au->le = l;  // make this current the event of interest
 			aup_list_first(l);
+			r = aup_list_get_cur(l);
+			free_interpretation_list();
+			load_interpretation_list(r->interp);
 			aup_list_first_field(l);
+
 			if (au->callback) {
 				(*au->callback)(au, AUPARSE_CB_EVENT_READY,
 					au->callback_user_data);
@@ -917,7 +929,7 @@ static void auparse_destroy_common(auparse_state_t *au)
 		au->in = NULL;
 	}
 	free_interpretation_list();
-	clear_classify(&au->cl_data);
+	clear_normalizer(&au->norm_data);
 	au_lol_clear(au->au_lo, 0);
 	free(au->au_lo);
 	free(au);
@@ -1099,7 +1111,7 @@ static int extract_timestamp(const char *b, au_event_t *e)
 		// Optionally grab the node - may or may not be included
 		if (*ptr == 'n') {
 			e->host = strdup(ptr+5);
-			(void)audit_strsplit(NULL); // Bump along to the next one
+			(void)audit_strsplit(NULL);// Bump along to next one
 		}
 		// at this point we have type=
 		ptr = audit_strsplit(NULL);
@@ -1118,16 +1130,14 @@ static int extract_timestamp(const char *b, au_event_t *e)
 
 				if (str2event(ptr, e) == 0)
 					rc = 0;
-//				else {
-//					audit_msg(LOG_ERROR,
-//					  "Error extracting time stamp (%s)\n",
-//						ptr);
-//				}
 			}
 			// else we have a bad line
 		}
 		// else we have a bad line
 	}
+	if (rc)
+		free(e->host);
+
 	// else we have a bad line
 	return rc;
 }
@@ -1340,15 +1350,19 @@ static int au_auparse_next_event(auparse_state_t *au)
 	/*
 	 * Deal with Python memory management issues where it issues a
 	 * auparse_destroy() call after an auparse_init() call but then wants
-	 * to still work with auparse data. Bascially, we assume if the user
+	 * to still work with auparse data. Basically, we assume if the user
 	 * wants to parse for events (calling auparse_next_event()) we accept
 	 * that they expect the memory structures to exist. This is a bit
 	 * 'disconcerting' but the au_lol capability is a patch trying to
 	 * redress a singleton approach to event processing.
 	 */
 	if (au->au_lo->array == NULL && au->au_lo->maxi == -1) {
+#ifdef	LOL_EVENTS_DEBUG01
+		if (debug) printf("Creating lol array\n");
+#endif	/* LOL_EVENTS_DEBUG01 */
 		au_lol_create(au->au_lo);
 	}	
+
 	/*
 	 * First see if we have any empty events but with an allocated event
 	 * list. These would have just been processed, so we can free them
@@ -1356,7 +1370,7 @@ static int au_auparse_next_event(auparse_state_t *au)
 	for (i = 0; i <= au->au_lo->maxi; i++) {
 		au_lolnode *cur = &au->au_lo->array[i];
 		if (cur->status == EBS_EMPTY && cur->l) {
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 			if (debug) {printf("Freeing at start "); print_list_t(cur->l);}
 #endif	/* LOL_EVENTS_DEBUG01 */
 			aup_list_clear(cur->l);
@@ -1379,7 +1393,7 @@ static int au_auparse_next_event(auparse_state_t *au)
 		load_interpretation_list(r->interp);
 		aup_list_first_field(l);
 		au->le = l;
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 		if (debug) print_lol("upfront", au->au_lo);
 #endif	/* LOL_EVENTS_DEBUG01 */
 		return 1;
@@ -1391,7 +1405,7 @@ static int au_auparse_next_event(auparse_state_t *au)
 		for (i = 0; i <= au->au_lo->maxi; i++) {
 			au_lolnode *cur = &au->au_lo->array[i];
 			if (cur->status == EBS_EMPTY && cur->l) {
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 				if (debug) {printf("Freeing at loop"); print_list_t(cur->l);}
 #endif	/* LOL_EVENTS_DEBUG01 */
 				aup_list_clear(cur->l);
@@ -1401,9 +1415,11 @@ static int au_auparse_next_event(auparse_state_t *au)
 			}
 		}
 		rc = retrieve_next_line(au);
+#ifdef	LOL_EVENTS_DEBUG01
 		if (debug) printf("next_line(%d) '%s'\n", rc, au->cur_buf);
+#endif	/* LOL_EVENTS_DEBUG01 */
 		if (rc == 0) {
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 			if (debug) printf("Empty line\n");
 #endif	/* LOL_EVENTS_DEBUG01 */
 			return 0;	/* NO data now */
@@ -1413,7 +1429,9 @@ static int au_auparse_next_event(auparse_state_t *au)
 			 * We are at EOF, so see if we have any accumulated
 			 * events.
 			 */
+#ifdef	LOL_EVENTS_DEBUG01
 			if (debug) printf("EOF\n");
+#endif	/* LOL_EVENTS_DEBUG01 */
 			au_terminate_all_events(au);
 			if ((l = au_get_ready_event(au, 0)) != NULL) {
 				rnode *r;
@@ -1424,20 +1442,24 @@ static int au_auparse_next_event(auparse_state_t *au)
 				load_interpretation_list(r->interp);
 				aup_list_first_field(l);
 				au->le = l;
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 				if (debug) print_lol("eof termination",au->au_lo);
 #endif	/* LOL_EVENTS_DEBUG01 */
 				return 1;
 			}
 			return 0;
 		} else if (rc < 0) {
+#ifdef	LOL_EVENTS_DEBUG01
 			/* Straight error */
 			if (debug) printf("Error %d\n", rc);
+#endif	/* LOL_EVENTS_DEBUG01 */
 			return -1;
 		}
 		/* So we got a successful read ie rc > 0 */
 		if (extract_timestamp(au->cur_buf, &e)) {
+#ifdef	LOL_EVENTS_DEBUG01
 			if (debug) printf("Malformed line:%s\n", au->cur_buf);
+#endif	/* LOL_EVENTS_DEBUG01 */
 			continue;
 		}
 
@@ -1449,13 +1471,15 @@ static int au_auparse_next_event(auparse_state_t *au)
 			au_lolnode *cur = &au->au_lo->array[i];
 			if (cur->status == EBS_BUILDING) {
 				if (events_are_equal(&cur->l->e, &e)) {
+#ifdef	LOL_EVENTS_DEBUG01
 					if (debug) printf("Adding event to building event\n");
+#endif	/* LOL_EVENTS_DEBUG01 */
 					aup_list_append(cur->l, au->cur_buf,
 						au->list_idx, au->line_number);
 					au->cur_buf = NULL;
 					free((char *)e.host);
 					au_check_events(au,  e.sec);
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 					if (debug) print_lol("building",au->au_lo);
 #endif	/* LOL_EVENTS_DEBUG01 */
 					/* we built something, so break out */
@@ -1468,14 +1492,21 @@ static int au_auparse_next_event(auparse_state_t *au)
 			continue;
 
 		/* So create one */
+#ifdef	LOL_EVENTS_DEBUG01
 		if (debug) printf("First record in new event, initialize event\n");
+#endif	/* LOL_EVENTS_DEBUG01 */
 		if ((l=(event_list_t *)malloc(sizeof(event_list_t))) == NULL) {
+			free((char *)e.host);
 			return -1;
 		}
 		aup_list_create(l);
 		aup_list_set_event(l, &e);
 		aup_list_append(l, au->cur_buf, au->list_idx, au->line_number);
 		if (au_lol_append(au->au_lo, l) == NULL) {
+			free((char *)e.host);
+#ifdef	LOL_EVENTS_DEBUG01
+			if (debug) printf("error appending to lol\n");
+#endif	/* LOL_EVENTS_DEBUG01 */
 			return -1;
 		}
 		au->cur_buf = NULL;
@@ -1490,7 +1521,7 @@ static int au_auparse_next_event(auparse_state_t *au)
 			load_interpretation_list(r->interp);
 			aup_list_first_field(l);
 			au->le = l;
-#if	LOL_EVENTS_DEBUG01
+#ifdef	LOL_EVENTS_DEBUG01
 			if (debug) print_lol("basic", au->au_lo);
 #endif	/* LOL_EVENTS_DEBUG01 */
 			return 1;
@@ -1501,7 +1532,7 @@ static int au_auparse_next_event(auparse_state_t *au)
 // Brute force go to next event. Returns < 0 on error, 0 no data, > 0 success
 int auparse_next_event(auparse_state_t *au)
 {
-	clear_classify(&au->cl_data);
+	clear_normalizer(&au->norm_data);
 	return au_auparse_next_event(au);
 }
 
