@@ -1,5 +1,5 @@
 /* internal.h -- 
- * Copyright 2006-07,2013-16 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2006-07,2013-17 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -26,16 +26,13 @@
 #include "ellist.h"
 #include "auditd-config.h"
 #include "data_buf.h"
-#include "classify-llist.h"
+#include "normalize-llist.h"
 #include "dso.h"
 #include <stdio.h>
 
 /* This is what state the parser is in */
 typedef enum { EVENT_EMPTY, EVENT_ACCUMULATING, EVENT_EMITTED } auparser_state_t;
 
-#define LOL_EVENTS_DEBUG01      0       // add debug for list of list event
-                                        // processing
-
 /*
  * NOTES:
  * Auditd events are made up of one or more records. The auditd system cannot
@@ -122,6 +119,7 @@ typedef struct subj
 	value_t primary;        // typically auid
 	value_t secondary;      // typically uid
 	cllist attr;            // List of attributes
+	const char *what;	// What the subject is
 }subject;
 
 typedef struct obj
@@ -134,15 +132,16 @@ typedef struct obj
 
 typedef struct data
 {
+	const char *evkind;
 	value_t session;
 	subject actor;
 	const char *action;
 	object thing;
 	value_t results;
 	const char *how;
-	classify_option_t opt;
+	normalize_option_t opt;
 	value_t key;
-} classify_data;
+} normalize_data;
 
 struct opaque
 {
@@ -182,7 +181,7 @@ struct opaque
 	auparse_esc_t escape_mode;
 	message_t message_mode;		// Where to send error messages
 	debug_message_t debug_message;	// Whether or not messages are debug or not
-	classify_data cl_data;
+	normalize_data norm_data;
 };
 
 AUDIT_HIDDEN_START
@@ -192,9 +191,9 @@ void clear_config(struct daemon_conf *config);
 int aup_load_config(auparse_state_t *au, struct daemon_conf *config, log_test_t lt);
 void free_config(struct daemon_conf *config);
 
-// classify.c
-void init_classify(classify_data *d);
-void clear_classify(classify_data *d);
+// normalize.c
+void init_normalizer(normalize_data *d);
+void clear_normalizer(normalize_data *d);
 
 AUDIT_HIDDEN_END
 
