@@ -1,6 +1,6 @@
 /*
 * nvlist.c - Minimal linked list library for name-value pairs
-* Copyright (c) 2006-07 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2006-07,2016 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved. 
 *
 * This library is free software; you can redistribute it and/or
@@ -38,15 +38,15 @@ void nvlist_create(nvlist *l)
 
 static void nvlist_last(nvlist *l)
 {
-        register nvnode* window;
-	
+        register nvnode* node;
+
 	if (l->head == NULL)
 		return;
 
-        window = l->head;
-	while (window->next)
-		window = window->next;
-	l->cur = window;
+	node = l->head;
+	while (node->next)
+		node = node->next;
+	l->cur = node;
 }
 
 nvnode *nvlist_next(nvlist *l)
@@ -84,20 +84,46 @@ void nvlist_append(nvlist *l, nvnode *node)
 	l->cnt++;
 }
 
+/*
+ * Its less code to make a fixup than a new append.
+ */
+void nvlist_interp_fixup(nvlist *l)
+{
+	if (l->cur) {
+		l->cur->interp_val = l->cur->val;
+		l->cur->val = NULL;
+	}
+}
+
+nvnode *nvlist_goto_rec(nvlist *l, int i)
+{
+	register nvnode* node;
+
+	node = l->head;       /* start at the beginning */
+	while (node) {
+		if (node->item == i) {
+			l->cur = node;
+			return node;
+		} else
+			node = node->next;
+	}
+	return NULL;
+}
+
 /*
  * This function will start at current index and scan for a name
  */
 int nvlist_find_name(nvlist *l, const char *name)
 {
-        register nvnode* window = l->cur;
+        register nvnode* node = l->cur;
 
-	while (window) {
-		if (strcmp(window->name, name) == 0) {
-			l->cur = window;
+	while (node) {
+		if (strcmp(node->name, name) == 0) {
+			l->cur = node;
 			return 1;
 		}
 		else
-			window = window->next;
+			node = node->next;
 	}
 	return 0;
 }
@@ -109,12 +135,12 @@ int nvlist_get_cur_type(const rnode *r)
 	return auparse_interp_adjust_type(r->type, l->cur->name, l->cur->val);
 }
 
-const char *nvlist_interp_cur_val(const rnode *r)
+const char *nvlist_interp_cur_val(const rnode *r, auparse_esc_t escape_mode)
 {
 	const nvlist *l = &r->nv;
 	if (l->cur->interp_val)
 		return l->cur->interp_val;
-	return interpret(r);
+	return interpret(r, escape_mode);
 }
 
 void nvlist_clear(nvlist* l)
@@ -122,6 +148,9 @@ void nvlist_clear(nvlist* l)
 	nvnode* nextnode;
 	register nvnode* current;
 
+	if (l->head == NULL)
+		return;
+
 	current = l->head;
 	while (current) {
 		nextnode=current->next;
