@@ -17,6 +17,14 @@ auparse_timestamp_compare: because AuEvent calls this via the cmp operator
 
 */
 
+/*
+ * Note about function return codes. If a C function returns:
+ *
+ * -1 and 0, then we return exception and none respectively
+ * -1, 0, 1, then we return exception, false, true respectively
+ *
+ */
+
 #if PY_MAJOR_VERSION > 2
 #define IS_PY3K
 #define MODINITERROR return NULL
@@ -418,12 +426,16 @@ AuParser_init(AuParser *self, PyObject *args, PyObject *kwds)
         PyMem_Del(buffers);
     } break;
     case AUSOURCE_DESCRIPTOR: {
-        int fd;
+        long fd;
         fd = PyObject_AsFileDescriptor(source);
         if (fd < 0) {
             PyErr_SetString(PyExc_ValueError, "source must be resolvable to a file descriptor when source_type is AUSOURCE_DESCRIPTOR");
             return -1;
         }
+        if ((self->au = auparse_init(source_type, (const void *)fd)) == NULL) {
+            PyErr_SetFromErrno(PyExc_EnvironmentError);
+            return -1;
+        }
     } break;
     case AUSOURCE_FILE_POINTER: {
         FILE* fp;
@@ -520,6 +532,24 @@ AuParser_flush_feed(AuParser *self)
     return NULL;
 }
 
+/********************************
+ * auparse_feed_has_data
+ ********************************/
+PyDoc_STRVAR(feed_has_data_doc,
+"feed_has_data() determines if there are any records that\n\
+ are accumulating but not yet ready to emit.\n\
+\n\
+Returns True if data left and false otherwise.\n\
+");
+static PyObject *
+AuParser_feed_has_data(AuParser *self)
+{
+    PARSER_CHECK;
+    if (auparse_feed_has_data(self->au) == 0)
+        Py_RETURN_FALSE;
+    Py_RETURN_TRUE;
+}
+
 /********************************
  * auparse_feed_age_events
  ********************************/
@@ -615,7 +645,7 @@ AuParser_set_escape_mode(AuParser *self, PyObject *args)
     if (!PyArg_ParseTuple(args, "i", &mode)) return NULL;
     auparse_set_escape_mode(self->au, mode);
 
-    return NULL;
+    Py_RETURN_NONE;
 }
 
 /********************************
@@ -959,7 +989,7 @@ a search condition is met. The possible values are:\n\
 \n\
 AUSEARCH_STOP_EVENT:\n\
 This one repositions the cursors to the first field of the first\n\
-record of the event con- taining the items searched for.\n\
+record of the event containing the items searched for.\n\
 \n\
 AUSEARCH_STOP_RECORD:\n\
 This one repositions the cursors to the first field of the record\n\
@@ -1060,6 +1090,435 @@ AuParser_parse_next_event(AuParser *self)
     return NULL;
 }
 
+
+
+/********************************
+ * aup_normalize
+ ********************************/
+PyDoc_STRVAR(aup_normalize_doc,
+"aup_normalize(opt) Normalize the audit event for uniform access to fields.\n\
+\n\
+aup_normalize() takes an argument to decide if it should also gather subject\n\
+and object attributes. The possible values are:\n\
+\n\
+NORM_OPT_ALL:\n\
+This means include subject and object attributes\n\
+\n\
+NORM_OPT_NO_ATTRS:\n\
+This means do not gather subject and object attributes\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize(AuParser *self, PyObject *args)
+{
+    int opt;
+    int result;
+
+    if (!PyArg_ParseTuple(args, "i", &opt)) return NULL;
+    PARSER_CHECK;
+    result = auparse_normalize(self->au, opt);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+
+/********************************
+ * aup_normalize_get_event_kind
+ ********************************/
+PyDoc_STRVAR(aup_normalize_get_event_kind_doc,
+"aup_normalize_get_event_kind() This returns a string that indicates what\n\
+kind of event this is.\n\
+\n\
+Raises exception (RuntimeError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_get_event_kind(AuParser *self)
+{
+    const char *kind = NULL;
+
+    PARSER_CHECK;
+    kind = auparse_normalize_get_event_kind(self->au);
+    if (kind == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'event_kind' has no value");
+        return NULL;
+    }
+    return Py_BuildValue("s", kind);
+}
+
+/********************************
+ * aup_normalize_session
+ ********************************/
+PyDoc_STRVAR(aup_normalize_session_doc,
+"aup_normalize_session() This function positions the internal cursor on\n\
+the session's field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_session(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_session(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_subject_primary
+ ********************************/
+PyDoc_STRVAR(aup_normalize_subject_primary_doc,
+"aup_normalize_subject_primary() This function positions the internal\n\
+cursor on the subject's field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_subject_primary(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_subject_primary(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_subject_secondary
+ ********************************/
+PyDoc_STRVAR(aup_normalize_subject_secondary_doc,
+"aup_normalize_subject_secondary() This function positions the internal\n\
+cursor on the subject's secondary field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_subject_secondary(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_subject_secondary(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_subject_first_attribute
+ ********************************/
+PyDoc_STRVAR(aup_normalize_subject_first_attribute_doc,
+"aup_normalize_subject_first_attribute() This function positions the internal\n\
+cursor on the subject's first attribute field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_subject_first_attribute(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_subject_first_attribute(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_subject_next_attribute
+ ********************************/
+PyDoc_STRVAR(aup_normalize_subject_next_attribute_doc,
+"aup_normalize_subject_next_attribute() This function positions the internal\n\
+cursor on the next subject's attribute field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_subject_next_attribute(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_subject_next_attribute(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_subject_kind
+ ********************************/
+PyDoc_STRVAR(aup_normalize_subject_kind_doc,
+"aup_normalize_subject_kind() This returns a string that indicates the\n\
+kind of account the subject is.\n\
+\n\
+Raises exception (RuntimeError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_subject_kind(AuParser *self)
+{
+    const char *kind = NULL;
+
+    PARSER_CHECK;
+    kind = auparse_normalize_subject_kind(self->au);
+    if (kind == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'subject_kind' has no value");
+        return NULL;
+    }
+    return Py_BuildValue("s", kind);
+}
+
+/********************************
+ * aup_normalize_get_action
+ ********************************/
+PyDoc_STRVAR(aup_normalize_get_action_doc,
+"aup_normalize_get_action() This returns a string that indicates the\n\
+subject's action.\n\
+\n\
+Raises exception (RuntimeError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_get_action(AuParser *self)
+{
+    const char *action = NULL;
+
+    PARSER_CHECK;
+    action = auparse_normalize_get_action(self->au);
+    if (action == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'action' has no value");
+        return NULL;
+    }
+    return Py_BuildValue("s", action);
+}
+
+/********************************
+ * aup_normalize_object_primary
+ ********************************/
+PyDoc_STRVAR(aup_normalize_object_primary_doc,
+"aup_normalize_object_primary() This function positions the internal\n\
+cursor on the object's field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_object_primary(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_object_primary(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_object_secondary
+ ********************************/
+PyDoc_STRVAR(aup_normalize_object_secondary_doc,
+"aup_normalize_object_secondary() This function positions the internal\n\
+cursor on the object's secondary field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_object_secondary(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_object_secondary(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_object_first_attribute
+ ********************************/
+PyDoc_STRVAR(aup_normalize_object_first_attribute_doc,
+"aup_normalize_object_first_attribute() This function positions the internal\n\
+cursor on the object's first attribute field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_object_first_attribute(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_object_first_attribute(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_object_next_attribute
+ ********************************/
+PyDoc_STRVAR(aup_normalize_object_next_attribute_doc,
+"aup_normalize_object_next_attribute() This function positions the internal\n\
+cursor on the next object's attribute field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_object_next_attribute(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_object_next_attribute(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_object_kind
+ ********************************/
+PyDoc_STRVAR(aup_normalize_object_kind_doc,
+"aup_normalize_object_kind() This returns a string that indicates the\n\
+kind of thing the object is.\n\
+\n\
+Raises exception (RuntimeError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_object_kind(AuParser *self)
+{
+    const char *kind = NULL;
+
+    PARSER_CHECK;
+    kind = auparse_normalize_object_kind(self->au);
+    if (kind == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'object_kind' has no value");
+        return NULL;
+    }
+    return Py_BuildValue("s", kind);
+}
+
+/********************************
+ * aup_normalize_get_results
+ ********************************/
+PyDoc_STRVAR(aup_normalize_get_results_doc,
+"aup_normalize_subject_primary() This function positions the internal\n\
+cursor on the results field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_get_results(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_get_results(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+/********************************
+ * aup_normalize_how
+ ********************************/
+PyDoc_STRVAR(aup_normalize_how_doc,
+"aup_normalize_how() This returns a string that indicates the\n\
+how the object is being accessed. This is usually a program.\n\
+\n\
+Raises exception (RuntimeError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_how(AuParser *self)
+{
+    const char *how = NULL;
+
+    PARSER_CHECK;
+    how = auparse_normalize_how(self->au);
+    if (how == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'how' has no value");
+        return NULL;
+    }
+    return Py_BuildValue("s", how);
+}
+
+/********************************
+ * aup_normalize_key
+ ********************************/
+PyDoc_STRVAR(aup_normalize_key_doc,
+"aup_normalize_key() This function positions the internal\n\
+cursor on the key field of the event.\n\
+\n\
+Returns True on success\n\
+Returns False if uninitialized\n\
+\n\
+Raises exception (ValueError) on error\n\
+");
+static PyObject *
+AuParser_aup_normalize_key(AuParser *self)
+{
+    int result;
+
+    PARSER_CHECK;
+    result = auparse_normalize_key(self->au);
+    if (result >  0) Py_RETURN_TRUE;
+    if (result == 0) Py_RETURN_FALSE;
+    PyErr_SetFromErrno(PyExc_ValueError);
+    return NULL;
+}
+
+
 /********************************
  * auparse_get_timestamp
  ********************************/
@@ -1092,12 +1551,13 @@ AuParser_get_timestamp(AuParser *self)
 
 /********************************
  * auparse_get_num_records
+ *
  ********************************/
 PyDoc_STRVAR(get_num_records_doc,
 "get_num_records() Get the number of records.\n\
 \n\
 Returns the number of records in the current event.\n\
-Raises exception (EnvironmentError) on error.\n\
+Raises exception (RuntimeError) on error.\n\
 ");
 static PyObject *
 AuParser_get_num_records(AuParser *self)
@@ -1107,7 +1567,7 @@ AuParser_get_num_records(AuParser *self)
     PARSER_CHECK;
     num_records = auparse_get_num_records(self->au);
     if (num_records == 0) {
-        PyErr_SetFromErrno(PyExc_EnvironmentError);
+        PyErr_SetString(PyExc_RuntimeError, "No records");
         return NULL;
     }
     return Py_BuildValue("i", num_records);
@@ -1253,6 +1713,7 @@ get_line_number will return the source input line number for\n\
 the current record of the current event. Line numbers start at 1.  If\n\
 the source input type is AUSOURCE_FILE_ARRAY the line numbering will\n\
 reset back to 1 each time a new life in the file array is opened.\n\
+Raises exception (RuntimeError) on error.\n\
 ");
 static PyObject *
 AuParser_get_line_number(AuParser *self)
@@ -1261,6 +1722,10 @@ AuParser_get_line_number(AuParser *self)
 
     PARSER_CHECK;
     value = auparse_get_line_number(self->au);
+    if (value == 0) {
+        PyErr_SetString(PyExc_RuntimeError, "No line number");
+        return NULL;
+    }
     return Py_BuildValue("I", value);
 }
 
@@ -1383,7 +1848,7 @@ PyDoc_STRVAR(find_field_doc,
 "find_field(name) Search for field name.\n\
 \n\
 find_field() will scan all records in an event to find the first\n\
-occurence of the field name passed to it. Searching begins from the\n\
+occurrence of the field name passed to it. Searching begins from the\n\
 cursor’s current position. The field name is stored for subsequent\n\
 searching.\n\
 \n\
@@ -1446,6 +1911,8 @@ get_field_name() allows access to the current field name of the\n\
 current record in the current event.\n\
 \n\
 Returns None if the field value is unavailable.\n\
+Returns String.\n\
+Raises exception (RuntimeError) on error\n\
 ");
 static PyObject *
 AuParser_get_field_name(AuParser *self)
@@ -1454,6 +1921,10 @@ AuParser_get_field_name(AuParser *self)
 
     PARSER_CHECK;
     name = auparse_get_field_name(self->au);
+    if (name == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'field name' is NULL");
+        return NULL;
+    }
     return Py_BuildValue("s", name);
 }
 
@@ -1466,7 +1937,8 @@ PyDoc_STRVAR(get_field_str_doc,
 get_field_str() allows access to the value in the current field of the\n\
 current record in the current event.\n\
 \n\
-Returns None if the field value is unavailable.\n\
+Returns String.\n\
+Raises exception (RuntimeError) on error\n\
 ");
 static PyObject *
 AuParser_get_field_str(AuParser *self)
@@ -1475,6 +1947,10 @@ AuParser_get_field_str(AuParser *self)
 
     PARSER_CHECK;
     value = auparse_get_field_str(self->au);
+    if (value == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'field str' is NULL");
+        return NULL;
+    }
     return Py_BuildValue("s", value);
 }
 
@@ -1490,7 +1966,7 @@ in the current event.\n\
 \n\
 Returns AUPARSE_TYPE_UNCLASSIFIED if the field’s data type has no\n\
 known description or is an integer. Otherwise it returns another enum.\n\
-Fields with the type AUPARSE_TYPE_ESCAPED must be interpretted to access\n\
+Fields with the type AUPARSE_TYPE_ESCAPED must be interpreted to access\n\
 their value since those field’s raw value is encoded.\n\
 ");
 static PyObject *
@@ -1512,7 +1988,8 @@ PyDoc_STRVAR(get_field_int_doc,
 get_field_int() allows access to the value as an int of the current\n\
 field of the current record in the current event.\n\
 \n\
-Returns None if the field value is unavailable.\n\
+Returns field's numeric value.\n\
+Raises exception (EnvironmentError) on error\n\
 ");
 static PyObject *
 AuParser_get_field_int(AuParser *self)
@@ -1522,15 +1999,16 @@ AuParser_get_field_int(AuParser *self)
     PARSER_CHECK;
     value = auparse_get_field_int(self->au);
     if (errno == 0) return Py_BuildValue("i", value);
-    Py_RETURN_NONE;
+    PyErr_SetFromErrno(PyExc_EnvironmentError);
+    return NULL;
 }
 
-// FIXME: can't tell if interpret is succesful, always returns some string in somewhat arbitrary format.
+// FIXME: can't tell if interpret is successful, always returns some string in somewhat arbitrary format.
 PyDoc_STRVAR(interpret_field_doc,
 "interpret_field() Return an interpretation of the current field as a string that has the chosen character escaping applied.\n\
 \n\
 If the field cannot be interpreted the field is returned unmodified.\n\
-Returns None if the field value is unavailable.\n\
+Raises exception (RuntimeError) on error\n\
 ");
 static PyObject *
 AuParser_interpret_field(AuParser *self)
@@ -1539,6 +2017,10 @@ AuParser_interpret_field(AuParser *self)
 
     PARSER_CHECK;
     value = auparse_interpret_field(self->au);
+    if (value == NULL) {
+        PyErr_SetString(PyExc_RuntimeError, "'interpretation' is NULL");
+        return NULL;
+    }
     return Py_BuildValue("s", value);
 }
 
@@ -1555,6 +2037,7 @@ PyMemberDef AuParser_members[] = {
 static PyMethodDef AuParser_methods[] = {
     {"feed",              (PyCFunction)AuParser_feed,              METH_VARARGS, feed_doc},
     {"flush_feed",        (PyCFunction)AuParser_flush_feed,        METH_NOARGS,  flush_feed_doc},
+    {"feed_has_data",     (PyCFunction)AuParser_feed_has_data,     METH_NOARGS,  feed_has_data_doc},
     {"feed_age_events",   (PyCFunction)AuParser_feed_age_events,   METH_NOARGS,  feed_age_events_doc},
     {"add_callback",      (PyCFunction)AuParser_add_callback,      METH_VARARGS, add_callback_doc},
     {"set_escape_mode",   (PyCFunction)AuParser_set_escape_mode,   METH_VARARGS, set_escape_mode_doc},
@@ -1569,6 +2052,23 @@ static PyMethodDef AuParser_methods[] = {
     {"search_clear",      (PyCFunction)AuParser_search_clear,      METH_NOARGS,  search_clear_doc},
     {"search_next_event", (PyCFunction)AuParser_search_next_event, METH_NOARGS,  search_next_event_doc},
     {"parse_next_event",  (PyCFunction)AuParser_parse_next_event,  METH_NOARGS,  parse_next_event_doc},
+    {"aup_normalize",     (PyCFunction)AuParser_aup_normalize,     METH_VARARGS, aup_normalize_doc},
+    {"aup_normalize_get_event_kind",  (PyCFunction)AuParser_aup_normalize_get_event_kind, METH_NOARGS, aup_normalize_get_event_kind_doc},
+    {"aup_normalize_session",  (PyCFunction)AuParser_aup_normalize_session, METH_NOARGS, aup_normalize_session_doc},
+    {"aup_normalize_subject_primary",  (PyCFunction)AuParser_aup_normalize_subject_primary, METH_NOARGS, aup_normalize_subject_primary_doc},
+    {"aup_normalize_subject_secondary",  (PyCFunction)AuParser_aup_normalize_subject_secondary, METH_NOARGS, aup_normalize_subject_secondary_doc},
+    {"aup_normalize_subject_first_attribute",  (PyCFunction)AuParser_aup_normalize_subject_first_attribute, METH_NOARGS, aup_normalize_subject_first_attribute_doc},
+    {"aup_normalize_subject_next_attribute",  (PyCFunction)AuParser_aup_normalize_subject_next_attribute, METH_NOARGS, aup_normalize_subject_next_attribute_doc},
+    {"aup_normalize_subject_kind",  (PyCFunction)AuParser_aup_normalize_subject_kind, METH_NOARGS, aup_normalize_subject_kind_doc},
+    {"aup_normalize_get_action",  (PyCFunction)AuParser_aup_normalize_get_action, METH_NOARGS, aup_normalize_get_action_doc},
+    {"aup_normalize_object_primary",  (PyCFunction)AuParser_aup_normalize_object_primary, METH_NOARGS, aup_normalize_object_primary_doc},
+    {"aup_normalize_object_secondary",  (PyCFunction)AuParser_aup_normalize_object_secondary, METH_NOARGS, aup_normalize_object_secondary_doc},
+    {"aup_normalize_object_first_attribute",  (PyCFunction)AuParser_aup_normalize_object_first_attribute, METH_NOARGS, aup_normalize_object_first_attribute_doc},
+    {"aup_normalize_object_next_attribute",  (PyCFunction)AuParser_aup_normalize_object_next_attribute, METH_NOARGS, aup_normalize_object_next_attribute_doc},
+    {"aup_normalize_object_kind",  (PyCFunction)AuParser_aup_normalize_object_kind, METH_NOARGS, aup_normalize_object_kind_doc},
+    {"aup_normalize_get_results",  (PyCFunction)AuParser_aup_normalize_get_results, METH_NOARGS, aup_normalize_get_results_doc},
+    {"aup_normalize_how", (PyCFunction)AuParser_aup_normalize_how, METH_NOARGS, aup_normalize_how_doc},
+    {"aup_normalize_key", (PyCFunction)AuParser_aup_normalize_key, METH_NOARGS, aup_normalize_key_doc},
     {"get_timestamp",     (PyCFunction)AuParser_get_timestamp,     METH_NOARGS,  get_timestamp_doc},
     {"get_num_records",   (PyCFunction)AuParser_get_num_records,   METH_NOARGS,  get_num_records_doc},
     {"first_record",      (PyCFunction)AuParser_first_record,      METH_NOARGS,  first_record_doc},
@@ -1656,6 +2156,7 @@ static PyTypeObject AuParserType = {
  *                                Module
  *===========================================================================*/
 
+#ifndef IS_PY3K
 PyDoc_STRVAR(auparse_doc,
 "Parsing library for audit messages.\n\
 \n\
@@ -1663,6 +2164,7 @@ The module defines the following exceptions:\n\
 \n\
 NoParser: Raised if the underlying C code parser is not bound to the AuParser object.\n\
 ");
+#endif
 
 static PyMethodDef module_methods[] = {
     {NULL}  /* Sentinel */
@@ -1740,6 +2242,10 @@ initauparse(void)
     PyModule_AddIntConstant(m, "AUSEARCH_STOP_RECORD",   AUSEARCH_STOP_RECORD);
     PyModule_AddIntConstant(m, "AUSEARCH_STOP_FIELD",    AUSEARCH_STOP_FIELD);
 
+    /* normalize_option_t */
+    PyModule_AddIntConstant(m, "NORM_OPT_ALL", NORM_OPT_ALL);
+    PyModule_AddIntConstant(m, "NORM_OPT_NO_ATTRS", NORM_OPT_NO_ATTRS);
+
     /* ausearch_rule_t */
     PyModule_AddIntConstant(m, "AUSEARCH_RULE_CLEAR",    AUSEARCH_RULE_CLEAR);
     PyModule_AddIntConstant(m, "AUSEARCH_RULE_OR",       AUSEARCH_RULE_OR);
