@@ -1,6 +1,6 @@
 /*
 * ausearch-lookup.c - Lookup values to something more readable
-* Copyright (c) 2005-06,2011-12,2015-16 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2005-06,2011-12,2015-17 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved. 
 *
 * This software may be freely redistributed and/or modified under the
@@ -321,7 +321,7 @@ char *unescape(const char *buf)
 	return str;
 }
 
-int need_sanitize(const unsigned char *s, unsigned int len)
+static int need_tty_escape(const unsigned char *s, unsigned int len)
 {
 	unsigned int i = 0;
 	while (i < len) {
@@ -332,7 +332,7 @@ int need_sanitize(const unsigned char *s, unsigned int len)
 	return 0;
 }
 
-void sanitize(const char *s, unsigned int len)
+static void tty_escape(const char *s, unsigned int len)
 {
 	unsigned int i = 0;
 	while (i < len) {
@@ -347,13 +347,108 @@ void sanitize(const char *s, unsigned int len)
 	}
 }
 
+static const char sh_set[] = "\"'`$\\!()| ";
+static unsigned int need_shell_escape(const char *s, unsigned int len)
+{
+	unsigned int i = 0, cnt = 0;
+	while (i < len) {
+		if (s[i] < 32)
+			cnt++;
+		else if (strchr(sh_set, s[i]))
+			cnt++;
+		i++;
+	}
+	return cnt;
+}
+
+static void shell_escape(const char *s, unsigned int len)
+{
+	unsigned int i = 0;
+	while (i < len) {
+		if ((unsigned char)s[i] < 32) {
+			putchar('\\');
+			putchar('0' + ((s[i] & 0300) >> 6));
+			putchar('0' + ((s[i] & 0070) >> 3));
+			putchar('0' + (s[i] & 0007));
+		} else if (strchr(sh_set, s[i])) {
+			putchar('\\');
+			putchar(s[i]);
+		} else
+			putchar(s[i]);
+		i++;
+	}
+}
+
+static const char quote_set[] = "\"'`$\\!()| ;#&*?[]<>{}";
+static unsigned int need_shell_quote_escape(const unsigned char *s, unsigned int len)
+{
+	unsigned int i = 0, cnt = 0;
+	while (i < len) {
+		if (s[i] < 32)
+			cnt++;
+		else if (strchr(quote_set, s[i]))
+			cnt++;
+		i++;
+	}
+	return cnt;
+}
+
+static void shell_quote_escape(const char *s, unsigned int len)
+{
+	unsigned int i = 0;
+	while (i < len) {
+		if ((unsigned char)s[i] < 32) {
+			putchar('\\');
+			putchar('0' + ((s[i] & 0300) >> 6));
+			putchar('0' + ((s[i] & 0070) >> 3));
+			putchar('0' + (s[i] & 0007));
+		} else if (strchr(quote_set, s[i])) {
+			putchar('\\');
+			putchar(s[i]);
+		} else
+			putchar(s[i]);
+		i++;
+	}
+}
+
+static unsigned int need_escaping(const char *s, unsigned int len)
+{
+	switch (escape_mode)
+	{
+		case AUPARSE_ESC_RAW:
+			break;
+		case AUPARSE_ESC_TTY:
+			return need_tty_escape(s, len);
+		case AUPARSE_ESC_SHELL:
+			return need_shell_escape(s, len);
+		case AUPARSE_ESC_SHELL_QUOTE:
+			return need_shell_quote_escape(s, len);
+	}
+	return 0;
+}
+
+static void escape(const char *s, unsigned int len)
+{
+	switch (escape_mode)
+	{
+		case AUPARSE_ESC_RAW:
+			return;
+		case AUPARSE_ESC_TTY:
+			return tty_escape(s, len);
+		case AUPARSE_ESC_SHELL:
+			return shell_escape(s, len);
+		case AUPARSE_ESC_SHELL_QUOTE:
+			return shell_quote_escape(s, len);
+	}
+}
+
 void safe_print_string_n(const char *s, unsigned int len, int ret)
 {
 	if (len > MAX_AUDIT_MESSAGE_LENGTH)
 		len = MAX_AUDIT_MESSAGE_LENGTH;
 
-	if (need_sanitize(s, len)) {
-		sanitize(s, len);
+	if (need_escaping(s, len)) {
+		escape(s, len);
 		if (ret)
 			putchar('\n');
 	} else if (ret)
