@@ -734,6 +734,17 @@ static int parse_path(const lnode *n, search_items *s)
 			rc = common_path_parser(s, str);
 			if (rc)
 				return rc;
+			term = str;
+
+			// Note that at this point we should be past beginning
+			// and around the path element. The type we search for
+			// is objtype or nametype. Searching for both will
+			// slow us down. So, I'm using what is common to both.
+			str = strstr(term, "type=");
+			if (str) {
+				str += 5;
+				s->filename->cur->key = strdup(str);
+			}
 		}
 	}
 	if (event_object) {
@@ -2005,6 +2016,9 @@ static int parse_kernel_anom(const lnode *n, search_items *s)
 		}
 	}
 
+	if (n->type == AUDIT_ANOM_PROMISCUOUS)
+		return 0; // Nothing else in the event
+
 	if (event_subject) {
 		// scontext
 		str = strstr(term, "subj=");
@@ -2061,26 +2075,26 @@ static int parse_kernel_anom(const lnode *n, search_items *s)
 		} 
 	}
 
-	if (n->type == AUDIT_SECCOMP) {
-		if (event_exe) {
-			// dont do this search unless needed
-			str = strstr(n->message, "exe=");
-			if (str) {
-				str += 4;
+	if (event_exe) {
+		// dont do this search unless needed
+		str = strstr(term, "exe=");
+		if (str) {
+			str += 4;
 			if (*str == '"') {
-					str++;
-					term = strchr(str, '"');
-					if (term == NULL)
-						return 13;
-					*term = 0;
-					s->exe = strdup(str);
-					*term = '"';
-				} else 
-					s->exe = unescape(str);
-			} else
-				return 14;
-		}
+				str++;
+				term = strchr(str, '"');
+				if (term == NULL)
+					return 13;
+				*term = 0;
+				s->exe = strdup(str);
+				*term = '"';
+			} else 
+				s->exe = unescape(str);
+		} else if (n->type != AUDIT_ANOM_ABEND)
+			return 14;
+	}
 
+	if (n->type == AUDIT_SECCOMP) {
 		// get arch
 		str = strstr(term, "arch=");
 		if (str == NULL) 
