@@ -413,8 +413,8 @@ static void csv_event(auparse_state_t *au,
 	if (csv_header_done == 0) {
 		csv_header_done = 1;
 		printf( "NODE,EVENT,DATE,TIME,%sSERIAL_NUM,EVENT_KIND,"
-			"SESSION,SUBJ_PRIME,SUBJ_SEC,%sACTION,RESULT,"
-			"OBJ_PRIME,OBJ_SEC,%sOBJ_KIND,HOW%s\n",
+			"SESSION,SUBJ_PRIME,SUBJ_SEC,SUBJ_KIND,%sACTION,"
+			"RESULT,OBJ_PRIME,OBJ_SEC,%sOBJ_KIND,HOW%s\n",
 		    extra_time ? "YEAR,MONTH,DAY,WEEKDAY,HOUR,GMT_OFFSET," : "",
 			extra_labels ? "SUBJ_LABEL," : "",
 			extra_labels ? "OBJ_LABEL," : "",
@@ -422,7 +422,7 @@ static void csv_event(auparse_state_t *au,
 	}
 
 	char tmp[20];
-	const char *item, *type, *evkind, *action, *str, *how;
+	const char *item, *type, *evkind, *subj_kind, *action, *str, *how;
 	int rc;
 	time_t t = auparse_get_time(au);
 	struct tm *tv = localtime(&t);
@@ -446,45 +446,62 @@ static void csv_event(auparse_state_t *au,
 			extra_labels ? NORM_OPT_ALL : NORM_OPT_NO_ATTRS);
 
 	//DATE
-	if (tv)
+	if (tv) {
 		strftime(tmp, sizeof(tmp), "%x", tv);
-	printf("%s,", tmp);
+		printf("%s", tmp);
+	}
+	putchar(',');
 
 	// TIME
-	if (tv)
+	if (tv) {
 		strftime(tmp, sizeof(tmp), "%T", tv);
-	printf("%s,", tmp);
+		printf("%s", tmp);
+	}
+	putchar(',');
 
 	if (extra_time) {
 		// YEAR
-		if (tv)
+		if (tv) {
 			strftime(tmp, sizeof(tmp), "%Y", tv);
-		printf("%s,", tmp);
+			printf("%s", tmp);
+		}
+		putchar(',');
 
 		// MONTH
-		if (tv)
+		if (tv) {
 			strftime(tmp, sizeof(tmp), "%m", tv);
-		printf("%s,", tmp);
+			printf("%s", tmp);
+		}
+		putchar(',');
 
 		// DAY
-		if (tv)
+		if (tv) {
 			strftime(tmp, sizeof(tmp), "%d", tv);
-		printf("%s,", tmp);
+			printf("%s", tmp);
+		}
+		putchar(',');
 
 		// WEEKDAY
-		if (tv)
+		if (tv) {
 			strftime(tmp, sizeof(tmp), "%u", tv);
-		printf("%s,", tmp);
+			printf("%s", tmp);
+		}
+		putchar(',');
 
 		// HOUR
-		if (tv)
+		if (tv) {
 			strftime(tmp, sizeof(tmp), "%k", tv);
-		printf("%s,", tmp);
-		char sign = tv->tm_gmtoff >= 0 ? '+' : '-';
-		unsigned long total = labs(tv->tm_gmtoff);
-		unsigned long hour = total/3600;
-		unsigned long min = (total - (hour * 3600))%60;
-		printf("%c%02lu:%02lu,", sign, hour, min);
+			printf("%s", tmp);
+		}
+		putchar(',');
+		if (tv) {
+			char sign = tv->tm_gmtoff >= 0 ? '+' : '-';
+			unsigned long total = labs(tv->tm_gmtoff);
+			unsigned long hour = total/3600;
+			unsigned long min = (total - (hour * 3600))%60;
+			printf("%c%02lu:%02lu", sign, hour, min);
+		}
+		putchar(',');
 	}
 
 	// SERIAL_NUMBER
@@ -526,6 +543,12 @@ static void csv_event(auparse_state_t *au,
 		printf("%s", auparse_interpret_field(au));
 	putchar(',');
 
+	// SUBJ_KIND
+	subj_kind = auparse_normalize_subject_kind(au);
+	if (subj_kind)
+		printf("%s", subj_kind);
+	putchar(',');
+
 	// SUBJ_LABEL
 	if (extra_labels) {
 		rc = auparse_normalize_subject_first_attribute(au);
